@@ -16,7 +16,98 @@ from Alexandria.general.console import print_color
 
 class canvas:
 
-    def method_style(self):
+    def method_backend(self):
+        if not isinstance(self.backend, type(None)):
+            try:
+                mpl.use(self.backend)
+            except AttributeError:
+                raise AttributeError('{} backend not supported with current Python configuration'.format(self.backend))
+
+        # matplotlib.use() must be called *before* pylab, matplotlib.pyplot,
+        # or matplotlib.backends is imported for the first time.
+
+    def method_fonts(self):
+        """
+        Fonts
+        Reference:
+            - https://matplotlib.org/2.0.2/users/customizing.html
+        Pyplot method:
+            plt.rcParams['<category>.<item>'] = <>
+        """
+        mpl.rc('font', family=self.font)
+        mpl.rc('font', serif="DejaVu Serif" if self.font == "serif" else self.font)
+        self.plt.rcParams['font.sans-serif'] ="DejaVu Serif" if self.font == "serif" else self.font
+        mpl.rc('font', cursive="Apple Chancery" if self.font == "serif" else self.font)
+        mpl.rc('font', fantasy="Chicago" if self.font == "serif" else self.font)
+        mpl.rc('font', monospace="Bitstream Vera Sans Mono" if self.font == "serif" else self.font)
+
+        mpl.rc('mathtext', fontset=self.math_font)
+
+        mpl.rc('text', color=self.font_color)
+        mpl.rc('xtick', color=self.font_color)
+        mpl.rc('ytick', color=self.font_color)
+        mpl.rc('axes', labelcolor=self.font_color)
+
+    def method_figure(self):
+        if not isinstance(self.style, type(None)):
+            self.plt.style.use(self.style)
+        self.fig = self.plt.figure(figsize=self.figsize)
+
+    def method_setup(self):
+        if isinstance(self.fig, type(None)):
+            if not self.plt.get_fignums():
+                self.method_figure()
+            else:
+                self.fig = self.plt.gcf()
+                self.ax = self.plt.gca()
+
+        if isinstance(self.ax, type(None)):
+            self.ax = self.fig.add_subplot(self.shape_and_position, adjustable='box', projection='3d')
+
+        self.ax.view_init(azim=self.azim, elev=self.elev)
+
+    def method_grid(self):
+        if self.grid:
+            self.plt.grid(linestyle=self.grid_lines, color=self.grid_color)
+        else:
+            self.ax.grid(self.grid)
+        if not self.show_axes:
+            self.plt.axis('off')
+
+    def method_pane_fill(self):
+        # Pane fill - False by default
+        self.ax.xaxis.pane.fill = False
+        self.ax.yaxis.pane.fill = False
+        self.ax.zaxis.pane.fill = False
+        if not isinstance(self.pane_fill, type(None)):
+            # Set pane fill to True if a color is provided
+            self.ax.xaxis.pane.fill = True if not isinstance(self.pane_fill, type(None)) else False
+            self.ax.yaxis.pane.fill = True if not isinstance(self.pane_fill, type(None)) else False
+            self.ax.zaxis.pane.fill = True if not isinstance(self.pane_fill, type(None)) else False
+            # Set pane fill color to that specified
+            self.ax.w_xaxis.set_pane_color(mpl.colors.to_rgba(self.pane_fill))
+            self.ax.w_yaxis.set_pane_color(mpl.colors.to_rgba(self.pane_fill))
+            self.ax.w_zaxis.set_pane_color(mpl.colors.to_rgba(self.pane_fill))
+
+        # Set edge colors
+        if self.blend_edges and not isinstance(self.pane_fill, type(None)):
+            spine_color = self.pane_fill if not isinstance(self.pane_fill, type(None)) else None
+        else:
+            spine_color = self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color
+
+        self.ax.xaxis.pane.set_edgecolor(spine_color)
+        self.ax.yaxis.pane.set_edgecolor(spine_color)
+        self.ax.zaxis.pane.set_edgecolor(spine_color)
+
+
+class attributes:
+
+    def method_background_color(self):
+        self.fig.patch.set_facecolor(self.background_color_figure)
+        self.ax.set_facecolor(self.background_color_plot)
+        self.ax.patch.set_alpha(self.background_alpha)
+
+    def method_workspace_style(self):
         if self.light:
             self.workspace_color = 'black' if isinstance(self.workspace_color, type(None)) else self.workspace_color
             self.workspace_color2 = (193 / 256, 193 / 256, 193 / 256) if isinstance(self.workspace_color2, type(
@@ -33,169 +124,15 @@ class canvas:
                 None)) else self.workspace_color2
             self.style = None
 
-    def method_setup(self):
-        if isinstance(self.fig, type(None)):
-            if not self.plt.get_fignums():
-                self.method_figure()
-            else:
-                self.fig = self.plt.gcf()
-                self.ax = self.plt.gca()
-
-        if isinstance(self.ax, type(None)):
-            self.ax = self.fig.add_subplot(self.shape_and_position, adjustable='box', projection='3d',
-                                           facecolor=self.background_color_figure)
-
-        self.ax.view_init(azim=self.azim, elev=self.elev)
-
-    def method_figure(self):
-        if not isinstance(self.style, type(None)):
-            self.plt.style.use(self.style)
-        self.fig = self.plt.figure(figsize=self.figsize)
-
-
-class attributes:
-
-    def method_background_color(self):
-        self.ax.patch.set_alpha(self.background_alpha)
-
-    def method_grid(self):
-        if self.grid is not False:
-            self.plt.grid(linestyle=self.grid_lines, color=self.grid_color)
-
-    def method_pane_fill(self):
-        # Pane fill and pane edge color
-        self.ax.xaxis.pane.fill = self.pane_fill
-        self.ax.yaxis.pane.fill = self.pane_fill
-        self.ax.zaxis.pane.fill = self.pane_fill
-        self.ax.xaxis.pane.set_edgecolor(self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
-        self.ax.yaxis.pane.set_edgecolor(self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
-
     def method_legend(self):
         if self.legend is True:
             legend_font = font_manager.FontProperties(family=self.font,
                                                       weight=self.legend_weight,
                                                       style=self.legend_style,
-                                                      size=self.legend_size)
+                                                      size=self.legend_size+self.font_size_increase)
             self.legend = self.fig.legend(loc=self.legend_loc, prop=legend_font,
                                           handleheight=self.legend_handleheight, ncol=self.legend_ncol)
 
-    def method_title(self):
-        if not isinstance(self.title, type(None)):
-
-            self.ax.set_title(self.title, y=self.title_y,
-                              fontname=self.font if isinstance(self.title_font, type(None)) else self.title_font,
-                              weight=self.title_weight,
-                              color=self.workspace_color if isinstance(self.title_color, type(None)) else self.title_color,
-                              size=self.title_size)
-            self.ax.title.set_position((0.5, self.title_y))
-
-    def method_axis_labels(self):
-        if not isinstance(self.x_label, type(None)):
-            if self.x_label_bold is True:
-                weight = 'bold'
-            else:
-                weight = 'normal'
-            self.ax.set_xlabel(self.x_label, fontname=self.font, weight=weight,
-                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
-                               size=self.x_label_size, labelpad=self.x_label_pad,
-                               rotation=self.x_label_rotation)
-        if not isinstance(self.y_label, type(None)):
-            if self.y_label_bold is True:
-                weight = 'bold'
-            else:
-                weight = 'normal'
-            self.ax.set_ylabel(self.y_label, fontname=self.font, weight=weight,
-                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
-                               size=self.y_label_size, labelpad=self.y_label_pad,
-                               rotation=self.y_label_rotation)
-        if not isinstance(self.z_label, type(None)):
-            if self.z_label_bold is True:
-                weight = 'bold'
-            else:
-                weight = 'normal'
-            self.ax.set_zlabel(self.z_label, fontname=self.font, weight=weight,
-                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
-                               size=self.z_label_size, labelpad=self.z_label_pad,
-                               rotation=self.z_label_rotation)
-
-    def method_spines(self):
-
-        for spine in self.ax.spines.values():
-            spine.set_color(self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
-
-        top = True
-        right = True
-        left = True
-        bottom = True
-
-        if not isinstance(self.spines_juggled, type(None)):
-            self.ax.xaxis._axinfo['juggled'] = self.spines_juggled
-        else:
-            # self.ax.xaxis._axinfo['juggled'] = (0, 2, 1)
-            # self.ax.xaxis._axinfo['juggled'] = (0, 1, 2)
-            self.ax.xaxis._axinfo['juggled'] = (1, 0, 2)
-
-        self.ax.tick_params(axis='both', which='both', top=top, right=right, left=left, bottom=bottom)
-
-    def method_ticks(self):
-        #   Color
-        if self.tick_color is not None:
-            self.ax.tick_params(axis='both', color=self.tick_color)
-
-            self.ax.w_xaxis.line.set_color(self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
-            self.ax.w_yaxis.line.set_color(self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
-            self.ax.w_zaxis.line.set_color(self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
-
-        #   Label size
-        if self.tick_label_size is not None:
-            self.ax.tick_params(axis='both', labelsize=self.tick_label_size)
-        #   Numeral size
-        for tick in self.ax.get_xticklabels():
-            tick.set_fontname(self.font)
-            tick.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
-        for tick in self.ax.get_yticklabels():
-            tick.set_fontname(self.font)
-            tick.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
-        for tick in self.ax.get_zticklabels():
-            tick.set_fontname(self.font)
-            tick.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
-        #   Float format
-        float_format = '%.' + str(self.tick_ndecimals) + 'f'
-        self.ax.xaxis.set_major_formatter(FormatStrFormatter(float_format))
-        self.ax.yaxis.set_major_formatter(FormatStrFormatter(float_format))
-        self.ax.zaxis.set_major_formatter(FormatStrFormatter(float_format))
-
-        # Tick number
-        if self.x_tick_number is not None:
-            self.ax.xaxis.set_major_locator(self.plt.MaxNLocator(self.x_tick_number, prune=self.prune))
-        if self.y_tick_number is not None:
-            self.ax.yaxis.set_major_locator(self.plt.MaxNLocator(self.y_tick_number, prune=self.prune))
-        if self.z_tick_number is not None:
-            self.ax.zaxis.set_major_locator(self.plt.MaxNLocator(self.z_tick_number, prune=self.prune))
-
-        # Tick label pad
-        if self.tick_label_pad is not None:
-            self.ax.tick_params(axis='both', pad=self.tick_label_pad)
-
-        # Tick rotation
-        if self.x_tick_rotation is not None:
-            self.ax.tick_params(axis='x', rotation=self.x_tick_rotation)
-        if self.y_tick_rotation is not None:
-            self.ax.tick_params(axis='y', rotation=self.y_tick_rotation)
-        if self.z_tick_rotation is not None:
-            self.ax.tick_params(axis='z', rotation=self.z_tick_rotation)
-
-    def method_scale(self):
-        # Scaling
-        max_scale = max([self.x_scale, self.y_scale, self.z_scale])
-        x_scale = self.x_scale / max_scale
-        y_scale = self.y_scale / max_scale
-        z_scale = self.z_scale / max_scale
-
-        # Reference:
-        # https://stackoverflow.com/questions/30223161/matplotlib-mplot3d-how-to-increase-the-size-of-an-axis-stretch-in-a-3d-plo
-        self.ax.get_proj = lambda: np.dot(Axes3D.get_proj(self.ax), np.diag([x_scale, y_scale, z_scale, 1]))
-
     def method_resize_axes(self):
         if self.resize_axes is True:
 
@@ -255,19 +192,163 @@ class attributes:
             self.ax.set_zlim3d(self.z_bounds[0] - self.y_lower_resize_pad,
                                self.z_bounds[1] + self.y_upper_resize_pad)
 
+    def method_title(self):
+        if not isinstance(self.title, type(None)):
+
+            self.ax.set_title(self.title, y=self.title_y,
+                              fontname=self.font if isinstance(self.title_font, type(None)) else self.title_font,
+                              weight=self.title_weight,
+                              color=self.workspace_color if isinstance(self.title_color, type(None)) else self.title_color,
+                              size=self.title_size+self.font_size_increase)
+            self.ax.title.set_position((0.5, self.title_y))
+
+    def method_axis_labels(self):
+        if not isinstance(self.x_label, type(None)):
+            self.ax.set_xlabel(self.x_label, fontname=self.font, weight=self.x_label_weight,
+                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
+                               size=self.x_label_size+self.font_size_increase, labelpad=self.x_label_pad,
+                               rotation=self.x_label_rotation)
+
+        if not isinstance(self.y_label, type(None)):
+            self.ax.set_ylabel(self.y_label, fontname=self.font, weight=self.y_label_weight,
+                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
+                               size=self.y_label_size+self.font_size_increase, labelpad=self.y_label_pad,
+                               rotation=self.y_label_rotation)
+
+        if not isinstance(self.z_label, type(None)):
+            self.ax.set_zlabel(self.z_label, fontname=self.font, weight=self.z_label_weight,
+                               color=self.workspace_color if self.font_color == self.workspace_color else self.font_color,
+                               size=self.z_label_size+self.font_size_increase, labelpad=self.z_label_pad,
+                               rotation=self.z_label_rotation)
+
+    def method_spines(self):
+
+        for spine in self.ax.spines.values():
+            spine.set_color(self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
+
+        if not isinstance(self.spines_juggled, type(None)):
+            self.ax.xaxis._axinfo['juggled'] = self.spines_juggled
+        else:
+            self.ax.xaxis._axinfo['juggled'] = (1, 0, 2)
+
+    def method_ticks(self):
+        # Tick number
+        if self.x_tick_number is not None:
+            # Tick locations
+            if not(isinstance(self.x_custom_tick_locations, type(None))):
+                low = self.x_custom_tick_locations[0]
+                high = self.x_custom_tick_locations[1]
+            else:
+                low = self.x.min()
+                high = self.x.max()
+            # Set usual ticks
+            if self.x_tick_number > 1:
+                ticklocs = np.linspace(low, high, self.x_tick_number)
+            # Special case: single tick
+            else:
+                ticklocs = np.array([low + (high - low)/2])
+            self.ax.set_xticks(ticklocs)
+        if self.y_tick_number is not None:
+            # Tick locations
+            if not (isinstance(self.y_custom_tick_locations, type(None))):
+                low = self.y_custom_tick_locations[0]
+                high = self.y_custom_tick_locations[1]
+            else:
+                low = self.y.min()
+                high = self.y.max()
+            # Set usual ticks
+            if self.y_tick_number > 1:
+                ticklocs = np.linspace(low, high, self.y_tick_number)
+            # Special case: single tick
+            else:
+                ticklocs = np.array([low + (high - low) / 2])
+            self.ax.set_yticks(ticklocs)
+        if self.z_tick_number is not None:
+            # Tick locations
+            if not (isinstance(self.z_custom_tick_locations, type(None))):
+                low = self.z_custom_tick_locations[0]
+                high = self.z_custom_tick_locations[1]
+            else:
+                low = self.z.min()
+                high = self.z.max()
+            # Set usual ticks
+            if self.z_tick_number > 1:
+                ticklocs = np.linspace(low, high, self.z_tick_number)
+            # Special case: single tick
+            else:
+                ticklocs = np.array([low + (high - low) / 2])
+            self.ax.set_zticks(ticklocs)
+        # Tick color
+        if self.tick_color is not None:
+            self.ax.tick_params(axis='both', color=self.tick_color)
+            self.ax.w_xaxis.line.set_color(
+                self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
+            self.ax.w_yaxis.line.set_color(
+                self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
+            self.ax.w_zaxis.line.set_color(
+                self.spine_color if not isinstance(self.spine_color, type(None)) else self.workspace_color)
+        # Custom tick labels
+        if not isinstance(self.x_custom_tick_labels, type(None)):
+            self.ax.set_xticklabels(self.x_custom_tick_labels)
+        if not isinstance(self.y_custom_tick_labels, type(None)):
+            self.ax.set_yticklabels(self.y_custom_tick_labels)
+        if not isinstance(self.z_custom_tick_labels, type(None)):
+            self.ax.set_zticklabels(self.z_custom_tick_labels)
+        # Label font, color, size
+        for label in self.ax.get_xticklabels():
+            label.set_fontname(self.font)
+            label.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
+            if not isinstance(self.x_tick_label_size, type(None)):
+                label.set_fontsize(self.x_tick_label_size+self.font_size_increase)
+            else:
+                label.set_fontsize(self.tick_label_size + self.font_size_increase)
+        for label in self.ax.get_yticklabels():
+            label.set_fontname(self.font)
+            label.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
+            if not isinstance(self.y_tick_label_size, type(None)):
+                label.set_fontsize(self.y_tick_label_size + self.font_size_increase)
+            else:
+                label.set_fontsize(self.tick_label_size + self.font_size_increase)
+        for label in self.ax.get_zticklabels():
+            label.set_fontname(self.font)
+            label.set_color(self.workspace_color if self.font_color == self.workspace_color else self.font_color)
+            if not isinstance(self.z_tick_label_size, type(None)):
+                label.set_fontsize(self.z_tick_label_size + self.font_size_increase)
+            else:
+                label.set_fontsize(self.tick_label_size + self.font_size_increase)
+        # Label float format
+        float_format = '%.' + str(self.tick_ndecimals) + 'f'
+        self.ax.xaxis.set_major_formatter(FormatStrFormatter(float_format))
+        self.ax.yaxis.set_major_formatter(FormatStrFormatter(float_format))
+        self.ax.zaxis.set_major_formatter(FormatStrFormatter(float_format))
+        # Label pad
+        if self.tick_label_pad is not None:
+            self.ax.tick_params(axis='both', pad=self.tick_label_pad)
+        # Label rotation
+        if self.x_tick_rotation is not None:
+            self.ax.tick_params(axis='x', rotation=self.x_tick_rotation)
+        if self.y_tick_rotation is not None:
+            self.ax.tick_params(axis='y', rotation=self.y_tick_rotation)
+        if self.z_tick_rotation is not None:
+            self.ax.tick_params(axis='z', rotation=self.z_tick_rotation)
+
+    def method_scale(self):
+        # Scaling
+        max_scale = max([self.x_scale, self.y_scale, self.z_scale])
+        x_scale = self.x_scale / max_scale
+        y_scale = self.y_scale / max_scale
+        z_scale = self.z_scale / max_scale
+
+        # Reference:
+        # https://stackoverflow.com/questions/30223161/matplotlib-mplot3d-how-to-increase-the-size-of-an-axis-stretch-in-a-3d-plo
+        self.ax.get_proj = lambda: np.dot(Axes3D.get_proj(self.ax), np.diag([x_scale, y_scale, z_scale, 1]))
+
 
 class plot(canvas, attributes):
 
     def init(self):
-        if not isinstance(self.backend, type(None)):
-            try:
-                mpl.use(self.backend)
-            except AttributeError:
-                raise AttributeError(
-                    '{} backend not supported with current Python configuration'.format(self.backend))
 
-        # matplotlib.use() must be called *before* pylab, matplotlib.pyplot,
-        # or matplotlib.backends is imported for the first time.
+        self.method_backend()
 
         self.plt = import_module("matplotlib.pyplot")
 
@@ -283,8 +364,12 @@ class plot(canvas, attributes):
 
     def main(self):
         # Canvas setup
-        self.method_style()
+        self.method_fonts()
         self.method_setup()
+        self.method_grid()
+        self.method_pane_fill()
+        self.method_background_color()
+        self.method_workspace_style()
 
         # Scale axes
         self.method_scale()
@@ -303,13 +388,10 @@ class plot(canvas, attributes):
         self.method_resize_axes()
 
         # Makeup
-        self.method_background_color()
         self.method_title()
         self.method_axis_labels()
         self.method_spines()
         self.method_ticks()
-        self.method_grid()
-        self.method_pane_fill()
 
         # Save
         self.method_save()
@@ -375,7 +457,7 @@ class color:
                                        labelpad=self.cb_ytitle_labelpad)
                     text = cbar.ax.yaxis.label
                     font = mpl.font_manager.FontProperties(family=self.font, style=self.cb_title_style,
-                                                           size=self.cb_title_size,
+                                                           size=self.cb_title_size+self.font_size_increase,
                                                            weight=self.cb_title_weight)
                     text.set_font_properties(font)
                 if self.cb_top_title is True:
@@ -383,17 +465,17 @@ class color:
                                       fontdict={'verticalalignment': 'baseline',
                                                 'horizontalalignment': 'left'},
                                       pad=self.cb_top_title_pad)
-                    cbar.ax.title.set_position((self.cb_top_title_x, self.cb_top_title_y))
+                    cbar.ax.title.set_position((self.x_cb_top_title, self.cb_top_title_y))
                     text = cbar.ax.title
                     font = mpl.font_manager.FontProperties(family=self.font, style=self.cb_title_style,
                                                            weight=self.cb_title_weight,
-                                                           size=self.cb_title_size)
+                                                           size=self.cb_title_size+self.font_size_increase)
                     text.set_font_properties(font)
             elif self.cb_orientation == 'horizontal':
                 cbar.ax.set_xlabel(self.cb_title, rotation=self.cb_title_rotation, labelpad=self.cb_ytitle_labelpad)
                 text = cbar.ax.xaxis.label
                 font = mpl.font_manager.FontProperties(family=self.font, style=self.cb_title_style,
-                                                       size=self.cb_title_size,
+                                                       size=self.cb_title_size+self.font_size_increase,
                                                        weight=self.cb_title_weight)
                 text.set_font_properties(font)
 
@@ -431,14 +513,14 @@ class line(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black",
+                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
                  # Figure, axis
-                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=54, elev=25,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=-137, elev=26,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10,
                  # Spines
-                 spines_juggled=(1, 0, 2), spine_color=None,
+                 spines_juggled=(1, 0, 2), spine_color=None, blend_edges=False,
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
@@ -453,30 +535,32 @@ class line(plot):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  z_upper_resize_pad=0, z_lower_resize_pad=0,
+                 # Axes
+                 show_axes=True,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color='darkred', cmap='RdBu_r', alpha=1,
                  # Title
-                 title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
+                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=7, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=7, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=7, z_label_rotation=None,
+                 x_label='x', x_label_weight='normal', x_label_size=12, x_label_pad=7, x_label_rotation=None,
+                 y_label='y', y_label_weight='normal', y_label_size=12, y_label_pad=7, y_label_rotation=None,
+                 z_label='z', z_label_weight='normal', z_label_size=12, z_label_pad=7, z_label_rotation=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
-                 z_tick_number=5, z_tick_labels=None,
+                 x_tick_number=5, x_tick_labels=None, x_custom_tick_labels=None, x_custom_tick_locations=None,
+                 y_tick_number=5, y_tick_labels=None, y_custom_tick_labels=None, y_custom_tick_locations=None,
+                 z_tick_number=5, z_tick_labels=None, z_custom_tick_labels=None, z_custom_tick_locations=None,
                  x_tick_rotation=None, y_tick_rotation=None, z_tick_rotation=None,
                  tick_color=None, tick_label_pad=4, tick_ndecimals=1,
                  # Tick labels
-                 tick_label_size=8.5, tick_label_size_x=None, tick_label_size_y=None, tick_label_size_z=None,
+                 tick_label_size=10, x_tick_label_size=None, y_tick_label_size=None, z_tick_label_size=None,
                  # Color bar
                  color_bar=False, extend='neither', shrink=0.75,
                  cb_title=None, cb_axis_labelpad=10, cb_tick_number=5,
                  cb_outline_width=None, cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0, cb_vmin=None, cb_vmax=None,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0, cb_vmin=None, cb_vmax=None,
                  cb_ticklabelsize=10,
                  # Legend
                  plot_label=None,
@@ -538,7 +622,7 @@ class scatter(plot, color):
 
     def __init__(self,
                  # Specifics
-                 x=None, y=None, z=None, point_size=5, marker="o",
+                 x=None, y=None, z=None, point_size=30, marker="o",
                  # Scale
                  x_scale=1,
                  y_scale=1,
@@ -546,13 +630,13 @@ class scatter(plot, color):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black",
+                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
-                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=54, elev=25,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=-137, elev=26,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10,
                  # Spines
-                 spines_juggled=(1, 0, 2), spine_color=None,
+                 spines_juggled=(1, 0, 2), spine_color=None, blend_edges=False,
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
@@ -567,30 +651,32 @@ class scatter(plot, color):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  z_upper_resize_pad=0, z_lower_resize_pad=0,
+                 # Axes
+                 show_axes=True,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color='darkred', cmap='RdBu_r', alpha=1, norm=None,
                  # Title
-                 title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
+                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=7, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=7, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=7, z_label_rotation=None,
+                 x_label='x', x_label_weight='normal', x_label_size=12, x_label_pad=7, x_label_rotation=None,
+                 y_label='y', y_label_weight='normal', y_label_size=12, y_label_pad=7, y_label_rotation=None,
+                 z_label='z', z_label_weight='normal', z_label_size=12, z_label_pad=7, z_label_rotation=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
-                 z_tick_number=5, z_tick_labels=None,
+                 x_tick_number=5, x_tick_labels=None, x_custom_tick_labels=None, x_custom_tick_locations=None,
+                 y_tick_number=5, y_tick_labels=None, y_custom_tick_labels=None, y_custom_tick_locations=None,
+                 z_tick_number=5, z_tick_labels=None, z_custom_tick_labels=None, z_custom_tick_locations=None,
                  x_tick_rotation=None, y_tick_rotation=None, z_tick_rotation=None,
                  tick_color=None, tick_label_pad=4, tick_ndecimals=1,
                  # Tick labels
-                 tick_label_size=8.5, tick_label_size_x=None, tick_label_size_y=None, tick_label_size_z=None,
+                 tick_label_size=10, x_tick_label_size=None, y_tick_label_size=None, z_tick_label_size=None,
                  # Color bar
                  color_bar=False, cb_pad=0.1, extend='neither',
                  cb_title=None, cb_orientation='vertical', cb_axis_labelpad=10, cb_tick_number=5, shrink=0.75,
                  cb_outline_width=None, cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0, cb_vmin=None, cb_vmax=None,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0, cb_vmin=None, cb_vmax=None,
                  cb_ticklabelsize=10, cb_hard_bounds=False,
                  # Legend
                  plot_label=None,
@@ -675,13 +761,13 @@ class surface(plot, surf):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black",
+                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
-                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=54, elev=25,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=-137, elev=26,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10,
                  # Spines
-                 spines_juggled=(1, 0, 2), spine_color=None,
+                 spines_juggled=(1, 0, 2), spine_color=None, blend_edges=False,
                  workspace_color=None, workspace_color2=None,
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
@@ -696,30 +782,32 @@ class surface(plot, surf):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  z_upper_resize_pad=0, z_lower_resize_pad=0,
+                 # Axes
+                 show_axes=True,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color='darkred', cmap='RdBu_r', alpha=1,
                  # Title
-                 title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
+                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=7, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=7, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=7, z_label_rotation=None,
+                 x_label='x', x_label_weight='normal', x_label_size=12, x_label_pad=7, x_label_rotation=None,
+                 y_label='y', y_label_weight='normal', y_label_size=12, y_label_pad=7, y_label_rotation=None,
+                 z_label='z', z_label_weight='normal', z_label_size=12, z_label_pad=7, z_label_rotation=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
-                 z_tick_number=5, z_tick_labels=None,
+                 x_tick_number=5, x_tick_labels=None, x_custom_tick_labels=None, x_custom_tick_locations=None,
+                 y_tick_number=5, y_tick_labels=None, y_custom_tick_labels=None, y_custom_tick_locations=None,
+                 z_tick_number=5, z_tick_labels=None, z_custom_tick_labels=None, z_custom_tick_locations=None,
                  x_tick_rotation=None, y_tick_rotation=None, z_tick_rotation=None,
                  tick_color=None, tick_label_pad=4, tick_ndecimals=1,
                  # Tick labels
-                 tick_label_size=8.5, tick_label_size_x=None, tick_label_size_y=None, tick_label_size_z=None,
+                 tick_label_size=10, x_tick_label_size=None, y_tick_label_size=None, z_tick_label_size=None,
                  # Color bar
                  color_bar=False, cb_pad=0.1, extend='neither',
                  cb_title=None, cb_orientation='vertical', cb_axis_labelpad=10, cb_tick_number=5, shrink=0.75,
                  cb_outline_width=None, cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0, cb_vmin=None, cb_vmax=None,
+                 cb_y_title=False, cb_top_title_pad=None, x_cb_top_title=0, cb_vmin=None, cb_vmax=None,
                  cb_ticklabelsize=10, cb_hard_bounds=False,
                  # Legend
                  plot_label=None,
